==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Test/Gui/Resources/translations/Test_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD Unit-Тест</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Сбои и ошибки</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Описание</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Запуск</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>Помощь</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>О программе</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>Закрыть</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Простой</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Прогресс</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Осталось:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Ошибки:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Сбои:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Выполнить:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Тестировать</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Выберите название теста:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Справка</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>О Unit-тесте FreeCAD</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (C) Вернер Майер 
FreeCAD UnitTest является частью FreeCAD и поддерживает написание Unit тестов для собственных модулей.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Введите имя вызываемого объекта при вызове которого, бедет возвтащаться TestCase. Кликните 'start' и, таким образом, проверка будет выполнена.

Выполните двойной щелчок на ошибке в древовидном виджете для дополнительной информации о ней, включая  стек вызовов.</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Test/Gui/Resources/translations/Test_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Сбои и ошибки</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Описание</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Запуск</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>Помощь</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>О программе</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>Закрыть</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>В ожидании</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Прогресс</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Осталось:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Ошибки:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Сбои:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Выполнить:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Тест</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Выберите название теста:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Справка</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>О FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (C) Вернер Майер 
FreeCAD UnitTest является частью FreeCAD и поддерживает написание Unit тестов для собственных модулей.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Введите имя вызываемого объекта при вызове которого, будет возвращаться TestCase. Кликните 'Запуск' и, тест будет запущен.

Сделайте двойной щелчок на ошибке в древовидном списке для дополнительной информации о ней, включая стек вызовов.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Введите имя вызываемого объекта при вызове которого, будет возвращаться TestCase.
Кликните 'Запуск' и, тест будет запущен.

Сделайте двойной щелчок на ошибке в древовидном списке для дополнительной информации о ней, включая стек вызовов.</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Copyright (C) Вернер Майер

FreeCAD UnitTest является частью FreeCAD и поддерживает написание Unit тестов для собственных модулей.</translation>
    </message>
  </context>
</TS>
